@@ -1,4 +1,4 @@
-from config.config_converter import excluded_fields, base_converter_params
+from converter.config.config_converter import excluded_fields, base_converter_params
 import logging
 import sys
 import warnings
