@@ -2,7 +2,7 @@ import logging
 import sys
 import warnings
 from converter.database_worker import DataBaseWorker
-from config.config_converter import (
+from converter.config.config_converter import (
     types_converter_dict,
     base_converter_params,
     excluded_fields,
@@ -24,6 +24,19 @@ logging.basicConfig(
 logging.captureWarnings(True)
 
 
+def save_ddl_to_file(sql, table_name, ddl_dir):
+    """
+    save ddl to file if you wish
+    :param sql: ddl to save
+    :param table_name:
+    :param ddl_dir:
+    :return:
+    """
+    f = open(ddl_dir + "/" + table_name + ".sql", "w", )
+    f.write(sql)
+    f.close()
+
+
 class FieldsConverter:
     def __init__(
             self,
@@ -103,17 +116,6 @@ class FieldsConverter:
             constrained=constrained
         )
 
-    def __save_ddl_to_file(self, ddl, table_name, ddl_dir):
-        """
-        save ddl to file if you wish
-        :param table_name:
-        :param ddl_dir:
-        :return:
-        """
-        f = open(ddl_dir + "/" + self.schema + "_" + table_name + ".sql", "w", )
-        f.write(ddl)
-        f.close()
-
     def update_column_type(self, column):
         """convert types between source and destination"""
         type_from = column["data_type"]
@@ -223,7 +225,7 @@ class FieldsConverter:
                 self.db_worker_to.conn.execute(sql)
                 logging.info("creating table {} is successfull".format(table))
             if dir_ddl is not None:
-                self.__save_ddl_to_file(ddl=sql, table_name=table, ddl_dir=dir_ddl)
+                save_ddl_to_file(sql=sql, table_name=table, ddl_dir=dir_ddl)
         if to_create:  # refit meta
             self.db_worker_to.init_meta()
         return result_list
